#include "uart.h"


/*----------------------------------------------------------------------------
 * Name:    Serial.c
 * Purpose: STM8 Low level serial functions
 * Note(s):
 *----------------------------------------------------------------------------*/

#include "me_iostm8s003f3.h"
#include "uart.h"


/* exact-width unsigned integer types */
typedef unsigned          char uint8_t;
typedef unsigned short     int uint16_t;
typedef unsigned           int uint32_t;


/*----------------------------------------------------------------------------
  Initialize UART pins, Baudrate
 *----------------------------------------------------------------------------*/
void uart_init (void) {
    UART1_CR1.M = 0; // 8 BIT DATA
    UART1_CR3.STOP = 0;
    UART1_BRR1 = 0X68 ;
    UART1_BRR2 = 0X03 ;
    UART1_CR2.TEN = 1;
    UART1_CR2.REN = 1; // Recieve Enabled
}


/*----------------------------------------------------------------------------
  Write character to Serial Port
 *----------------------------------------------------------------------------*/
int uart_send_char (char c) {
	while(!(UART1_SRA & MASK_UART1_SR_TXE));
	return(UART1_DR = c);        
        
}


/*----------------------------------------------------------------------------
  Read character from Serial Port   (blocking read)
 *----------------------------------------------------------------------------*/
int uart_get_char (void) {
       while (!(UART1_SR.RXNE));
       UART1_SR.RXNE = 0;
       return(UART1_DR);            
  
}


/*----------------------------------------------------------------------------
  Read character from Serial Port   (non blocking read)
 *----------------------------------------------------------------------------*/
int uart_get_char_nb (void) {
  if (UART1_SR.RXNE)
    return(UART1_DR);
  else
    return 0;
}


/*----------------------------------------------------------------------------
  Write character to Serial Port
 *----------------------------------------------------------------------------*/
void uart_send_string (unsigned char *s) {

  while (*s != 0) {
   uart_send_char(*s++);
  }
}



void uart_send_num(unsigned short int disp)
{
	uint16_t dispbuf[4];
	uint8_t i;

	dispbuf[3] = disp%10 + '0';
	dispbuf[2] = disp/10%10 + '0';
	dispbuf[1] = disp/10/10%10 + '0';
	dispbuf[0] = disp/10/10/10%10 + '0';
	for(i=0;i<4;i++)
		//UART0_SendByte(dispbuf[i]);
		uart_send_char (dispbuf[i]);	
}
